@@ -31,6 +31,7 @@ DBusGMainLoop(set_as_default=True)
 import gettext
 import logging
 import os
+import re
 import subprocess
 import sys
 import xapian
@@ -47,28 +48,36 @@ softwarecenter.netstatus.NETWORK_STATE
 
 # db imports
 from softwarecenter.db.application import Application
-from softwarecenter.db import DebFileApplication
+from softwarecenter.db import DebFileApplication, DebFileOpenError
 from softwarecenter.i18n import init_locale
 
 # misc imports
 from softwarecenter.plugin import PluginManager
 from softwarecenter.paths import SOFTWARE_CENTER_PLUGIN_DIRS
-from softwarecenter.enums import (Icons,
-                                  PkgStates,
-                                  ViewPages,
-                                  AppActions,
-                                  DB_SCHEMA_VERSION,
-                                  MOUSE_EVENT_FORWARD_BUTTON,
-                                  MOUSE_EVENT_BACK_BUTTON,
-                                  SOFTWARE_CENTER_TOS_LINK,
-                                  SOFTWARE_CENTER_NAME_KEYRING)
-from softwarecenter.utils import (clear_token_from_ubuntu_sso,
-                                  get_http_proxy_string_from_gsettings,
-                                  wait_for_apt_cache_ready,
-                                  ExecutionTime,
-                                  is_unity_running)
-from softwarecenter.ui.gtk3.utils import (get_sc_icon_theme,
-                                          init_sc_css_provider)
+from softwarecenter.enums import (
+    AppActions,
+    DB_SCHEMA_VERSION,
+    Icons,
+    MOUSE_EVENT_FORWARD_BUTTON,
+    MOUSE_EVENT_BACK_BUTTON,
+    PkgStates,
+    SearchSeparators,
+    SOFTWARE_CENTER_DEBUG_TABS,
+    SOFTWARE_CENTER_NAME_KEYRING,
+    SOFTWARE_CENTER_TOS_LINK,
+    ViewPages,
+)
+from softwarecenter.utils import (
+    clear_token_from_ubuntu_sso_sync,
+    get_http_proxy_string_from_gsettings,
+    wait_for_apt_cache_ready,
+    ExecutionTime,
+    is_unity_running,
+)
+from softwarecenter.ui.gtk3.utils import (
+    get_sc_icon_theme,
+    init_sc_css_provider,
+)
 from softwarecenter.version import VERSION
 from softwarecenter.db.database import StoreDatabase
 try:
@@ -87,10 +96,14 @@ from softwarecenter.ui.gtk3.panes.availablepane import AvailablePane
 from softwarecenter.ui.gtk3.panes.historypane import HistoryPane
 from softwarecenter.ui.gtk3.panes.globalpane import GlobalPane
 from softwarecenter.ui.gtk3.panes.pendingpane import PendingPane
-from softwarecenter.ui.gtk3.session.appmanager import (ApplicationManager,
-                                                       get_appmanager)
+from softwarecenter.ui.gtk3.session.appmanager import (
+    ApplicationManager,
+    get_appmanager,
+    )
 from softwarecenter.ui.gtk3.session.viewmanager import (
-    ViewManager, get_viewmanager)
+    ViewManager,
+    get_viewmanager,
+    )
 from softwarecenter.ui.gtk3.widgets.recommendations import (
     RecommendationsOptInDialog)
 
@@ -112,6 +125,10 @@ from softwarecenter.db.pkginfo import get_pkg_info
 from gi.repository import Gdk
 
 LOG = logging.getLogger(__name__)
+PACKAGE_PREFIX = 'apt:'
+# "apt:///" is a valid prefix for 'apt:pkgname' in alt+F2 in gnome
+PACKAGE_PREFIX_REGEX = re.compile('^%s(?:/{2,3})*' % PACKAGE_PREFIX)
+SEARCH_PREFIX = 'search:'
 
 
 # py3 compat
@@ -119,6 +136,64 @@ def callable(func):
     return isinstance(func, collections.Callable)
 
 
+def parse_packages_args(packages):
+    search_text = ''
+    app = None
+
+    # avoid treating strings as sequences ('foo' should not be 'f', 'o', 'o')
+    if isinstance(packages, basestring):
+        packages = (packages,)
+
+    if not isinstance(packages, collections.Iterable):
+        LOG.warning('show_available_packages: argument is not an iterable %r',
+            packages)
+        return search_text, app
+
+    items = []  # make a copy of the given sequence
+    for arg in packages:
+        # support both "pkg1 pkg" and "pkg1,pkg2" (and "pkg1,pkg2 pkg3")
+        if "," in arg:
+            items.extend(arg.split(SearchSeparators.PACKAGE))
+        else:
+            items.append(arg)
+
+    if len(items) > 0:
+        # allow s-c to be called with a search term
+        if items[0].startswith(SEARCH_PREFIX):
+            # remove the initial search prefix
+            items[0] = items[0].replace(SEARCH_PREFIX, '', 1)
+            search_text = SearchSeparators.REGULAR.join(items)
+        else:
+            # strip away the initial apt: prefix, if present
+            items[0] = re.sub(PACKAGE_PREFIX_REGEX, '', items[0])
+            if len(items) > 1:
+                # turn multiple packages into a search with "," as separator
+                search_text = SearchSeparators.PACKAGE.join(items)
+
+    if not search_text and len(items) == 1:
+        request = items[0]
+        # are we dealing with a path?
+        if os.path.exists(request) and not os.path.isdir(request):
+            if not request.startswith('/'):
+                # we may have been given a relative path
+                request = os.path.abspath(request)
+            # will raise DebOpenFileError if request is invalid
+            app = DebFileApplication(request)
+        else:
+            # package from archive
+            # if there is a "/" in the string consider it as tuple
+            # of (pkgname, appname) for exact matching (used by
+            # e.g. unity
+            (pkgname, sep, appname) = request.partition("/")
+            if pkgname or appname:
+                app = Application(appname, pkgname)
+            else:
+                LOG.warning('show_available_packages: received %r but '
+                    'can not build an Application from it.', request)
+
+    return search_text, app
+
+
 class SoftwarecenterDbusController(dbus.service.Object):
     """
     This is a helper to provide the SoftwarecenterIFace
@@ -158,13 +233,16 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
     # the size of the icon for dialogs
     APP_ICON_SIZE = Gtk.IconSize.DIALOG
 
+    START_DBUS = True
+
     def __init__(self, datadir, xapian_base_path, options, args=None):
-        # setup dbus and exit if there is another instance already
-        # running
-        self.setup_dbus_or_bring_other_instance_to_front(args)
+        self.dbusControler = None
+        if self.START_DBUS:
+            # setup dbus and exit if there is another instance already running
+            self.setup_dbus_or_bring_other_instance_to_front(args)
 
         self.datadir = datadir
-        SimpleGtkbuilderApp.__init__(self,
+        super(SoftwareCenterAppGtk3, self).__init__(
                                      datadir + "/ui/gtk3/SoftwareCenter.ui",
                                      "software-center")
         gettext.bindtextdomain("software-center", "/usr/share/locale")
@@ -172,7 +250,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
 
         init_locale()
 
-        if "SOFTWARE_CENTER_DEBUG_TABS" in os.environ:
+        if SOFTWARE_CENTER_DEBUG_TABS:
             self.notebook_view.set_show_tabs(True)
 
         # distro specific stuff
@@ -273,6 +351,10 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             self.vbox1.pack_start(self.global_pane, False, False, 0)
             self.vbox1.reorder_child(self.global_pane, 1)
 
+            # start with the toolbar buttons insensitive and don't make them
+            # sensitive until the panel elements are ready
+            self.global_pane.view_switcher.set_sensitive(False)
+
             # available pane
             self.available_pane = AvailablePane(self.cache,
                                                 self.db,
@@ -292,8 +374,8 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
                                                 self.distro,
                                                 self.icons,
                                                 self.datadir)
-            #~ self.installed_pane.connect("installed-pane-created",
-                #~ self.on_installed_pane_created)
+            self.installed_pane.connect("installed-pane-created",
+                self.on_installed_pane_created)
             self.view_manager.register(self.installed_pane,
                 ViewPages.INSTALLED)
 
@@ -381,7 +463,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
                 self.menu_file.remove(self.separator_login)
         else:
             # running the agent will trigger a db reload so we do it later
-            GObject.timeout_add_seconds(30, self._run_software_center_agent)
+            GObject.timeout_add_seconds(3, self._run_software_center_agent)
 
         # keep the cache clean
         GObject.timeout_add_seconds(15, self._run_expunge_cache_helper)
@@ -455,8 +537,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             if proxy:
                 os.environ["http_proxy"] = proxy
             else:
-                if "http_proxy" in os.environ:
-                    del os.environ["http_proxy"]
+                os.environ.pop("http_proxy", None)
         except Exception as e:
             # if no gnome settings are installed, do not mess with
             # http_proxy
@@ -480,9 +561,12 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
                         "recommendations-opt-out",
                         self._on_recommendations_opt_out)
         self.menuitem_recommendations.set_sensitive(True)
+        # set the main toolbar buttons sensitive
+        self.global_pane.view_switcher.set_sensitive(True)
 
-    #~ def on_installed_pane_created(self, widget):
-        #~ pass
+    def on_installed_pane_created(self, widget):
+        # set the main toolbar buttons sensitive
+        self.global_pane.view_switcher.set_sensitive(True)
 
     def _on_recommendations_opt_in(self, rec_panel):
         self._update_recommendations_menuitem(opted_in=True)
@@ -498,6 +582,7 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             self.menuitem_recommendations.set_label(
                                             _(u"Turn On Recommendations…"))
 
+    @wait_for_apt_cache_ready
     def _upload_recommendations_profile(self):
         recommender_agent = self._get_recommender_agent()
         if recommender_agent.is_opted_in():
@@ -517,6 +602,18 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
     def on_review_stats_loaded(self, reviews):
         LOG.debug("on_review_stats_loaded: '%s'" % len(reviews))
 
+    def destroy(self):
+        """Destroy this instance and every used resource."""
+        self.window_main.destroy()
+
+        # remove global instances of Managers
+        self.app_manager.destroy()
+        self.view_manager.destroy()
+
+        if self.dbusControler is not None:
+            # ensure that the dbus controller is really gone
+            self.dbusControler.stop()
+
     def close_app(self):
         """ perform tasks like save-state etc when the application is
             exited
@@ -531,15 +628,14 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         if hasattr(self, "glaunchpad"):
             self.glaunchpad.shutdown()
         self.save_state()
+        self.destroy()
+
         # this will not throw exceptions in pygi but "only" log via g_critical
         # to the terminal but it might in the future so we add a handler here
         try:
             Gtk.main_quit()
         except:
             LOG.exception("Gtk.main_quit failed")
-        # ensure that the dbus controller is really gone, just for good
-        # measure
-        self.dbusControler.stop()
         # exit here explictely to ensure that no further gtk event loops or
         # threads run and cause havoc on exit (LP: #914393)
         sys.exit(0)
@@ -786,12 +882,14 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
     def on_menuitem_reinstall_purchases_activate(self, menuitem):
         self.view_manager.set_active_view(ViewPages.AVAILABLE)
         self.view_manager.search_entry.clear_with_no_signal()
-        self.available_pane.show_appview_spinner()
         if self.available_for_me_query:
             # we already have the list of available items, so just show it
+            # (no need for spinner here)
             self.available_pane.on_previous_purchases_activated(
                     self.available_for_me_query)
         else:
+            # show spinner as this may take some time
+            self.available_pane.show_appview_spinner()
             # fetch the list of available items and show it
             self._create_scagent_if_needed()
             self._login_via_dbus_sso()
@@ -811,7 +909,9 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             installed_purchases)
         if deauthorize:
             # clear the ubuntu SSO token for this account
-            clear_token_from_ubuntu_sso(SOFTWARE_CENTER_NAME_KEYRING)
+            # FIXME: as this is a sync call it maybe slow so we should
+            #        probably provide a async() version of this as well
+            clear_token_from_ubuntu_sso_sync(SOFTWARE_CENTER_NAME_KEYRING)
 
             # uninstall the list of purchased packages
             # TODO: do we need to check for dependencies and show a removal
@@ -963,7 +1063,6 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             self.active_pane.searchentry.select_region(0, -1)
 
     def on_menuitem_software_sources_activate(self, widget):
-        self.window_main.set_sensitive(False)
         # run software-properties-gtk
         window = self.window_main.get_window()
         if hasattr(window, 'xid'):
@@ -986,7 +1085,6 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
         # A return code of 1 means that the sources have changed
         if ret == 1:
             self.run_update_cache()
-        self.window_main.set_sensitive(True)
         # Stop monitoring
         return False
 
@@ -1209,66 +1307,49 @@ class SoftwareCenterAppGtk3(SimpleGtkbuilderApp):
             bus_name = dbus.service.BusName('com.ubuntu.Softwarecenter', bus)
             self.dbusControler = SoftwarecenterDbusController(self, bus_name)
 
+    @wait_for_apt_cache_ready
+    def show_app(self, app):
+        """Show 'app' in the installed pane if is installed.
+
+        If 'app' is not installed, show it in the available pane.
+
+        """
+        if (app.pkgname in self.cache and self.cache[app.pkgname].installed):
+            with ExecutionTime("installed_pane.init_view()"):
+                self.installed_pane.init_view()
+            with ExecutionTime("installed_pane.show_app()"):
+                self.installed_pane.show_app(app)
+        else:
+            self.available_pane.init_view()
+            self.available_pane.show_app(app)
+
     def show_available_packages(self, packages):
         """ Show packages given as arguments in the available_pane
             If the list of packages is only one element long show that,
             otherwise turn it into a comma seperated search
         """
-        # strip away the apt: prefix
-        if packages and packages[0].startswith("apt:///"):
-            # this is for 'apt:pkgname' in alt+F2 in gnome
-            packages[0] = packages[0].partition("apt:///")[2]
-        elif packages and packages[0].startswith("apt://"):
-            packages[0] = packages[0].partition("apt://")[2]
-        elif packages and packages[0].startswith("apt:"):
-            packages[0] = packages[0].partition("apt:")[2]
+        try:
+            search_text, app = parse_packages_args(packages)
+        except DebFileOpenError as e:
+            LOG.exception("show_available_packages: can not open %r, error:",
+                          packages)
+            dialogs.error(None,
+                          _("Error"),
+                          _("The file “%s” could not be opened.") % e.path)
+            search_text = app = None
 
-        # allow s-c to be called with a search term
-        if packages and packages[0].startswith("search:"):
-            packages[0] = packages[0].partition("search:")[2]
+        LOG.info('show_available_packages: search_text is %r, app is %r.',
+                 search_text, app)
+
+        if search_text:
             self.available_pane.init_view()
-            self.available_pane.searchentry.set_text(" ".join(packages))
-            return
-
-        if len(packages) == 1:
-            request = packages[0]
-
-            # are we dealing with a path?
-            if os.path.exists(request) and not os.path.isdir(request):
-                if not request.startswith('/'):
-                # we may have been given a relative path
-                    request = os.path.join(os.getcwd(), request)
-                app = DebFileApplication(request)
-            else:
-                # package from archive
-                # if there is a "/" in the string consider it as tuple
-                # of (pkgname, appname) for exact matching (used by
-                # e.g. unity
-                (pkgname, sep, appname) = packages[0].partition("/")
-                app = Application(appname, pkgname)
-
-            @wait_for_apt_cache_ready
-            def show_app(self, app):
-                # if the pkg is installed, show it in the installed pane
-                if (app.pkgname in self.cache and
-                    self.cache[app.pkgname].installed):
-                    with ExecutionTime("installed_pane.init_view()"):
-                        self.installed_pane.init_view()
-                    with ExecutionTime("installed_pane.show_app()"):
-                        self.installed_pane.show_app(app)
-                else:
-                    self.available_pane.init_view()
-                    self.available_pane.show_app(app)
-            show_app(self, app)
-            return
-        elif len(packages) > 1:
-            # turn multiple packages into a search with ","
-            self.available_pane.init_view()
-            self.available_pane.searchentry.set_text(",".join(packages))
-            return
-        # normal startup, show the lobby (it will have a spinner when
-        # its not ready yet) - it will also initialize the view
-        self.view_manager.set_active_view(ViewPages.AVAILABLE)
+            self.available_pane.searchentry.set_text(search_text)
+        elif app is not None:
+            self.show_app(app)
+        else:
+            # normal startup, show the lobby (it will have a spinner when
+            # its not ready yet) - it will also initialize the view
+            self.view_manager.set_active_view(ViewPages.AVAILABLE)
 
     def restore_state(self):
         if self.config.has_option("general", "size"):
