@@ -22,20 +22,22 @@ from gi.repository import GObject
 from gi.repository import Gtk, Gdk
 #~ from gi.repository import Cairo
 import logging
-import os
 import xapian
 
 from softwarecenter.backend import get_install_backend
 from softwarecenter.db.database import Application
 from softwarecenter.db.enquire import AppEnquire
-from softwarecenter.enums import (SortMethods,
-                                  DEFAULT_SEARCH_LIMIT,
-                                  NonAppVisibility)
-
-from softwarecenter.utils import (ExecutionTime,
-                                  wait_for_apt_cache_ready,
-                                  utf8
-                                  )
+from softwarecenter.enums import (
+    DEFAULT_SEARCH_LIMIT,
+    NonAppVisibility,
+    SOFTWARE_CENTER_DEBUG_TABS,
+    SortMethods,
+)
+from softwarecenter.utils import (
+    ExecutionTime,
+    utf8,
+    wait_for_apt_cache_ready,
+)
 
 from softwarecenter.ui.gtk3.session.viewmanager import get_viewmanager
 from softwarecenter.ui.gtk3.widgets.actionbar import ActionBar
@@ -64,7 +66,6 @@ class DisplayState(object):
               'application': (type(None), Application),
               'limit': (int,),
               'filter': (type(None), AppFilter),
-              'previous_purchases_query': (type(None), xapian.Query),
               'vadjustment': (float, ),
             }
 
@@ -76,7 +77,6 @@ class DisplayState(object):
         self.application = None
         self.limit = 0
         self.filter = None
-        self.previous_purchases_query = None
         self.vadjustment = 0.0
 
     def __setattr__(self, name, val):
@@ -123,7 +123,8 @@ class DisplayState(object):
         self.search_term = ""
         self.application = None
         self.limit = 0
-        #~ self.filter = None
+        if self.filter:
+            self.filter.reset()
         self.vadjustment = 0.0
 
 
@@ -177,7 +178,7 @@ class SoftwarePane(Gtk.VBox, BasePane):
         self.back_forward = vm.get_global_backforward()
         # a notebook below
         self.notebook = Gtk.Notebook()
-        if not "SOFTWARE_CENTER_DEBUG_TABS" in os.environ:
+        if not SOFTWARE_CENTER_DEBUG_TABS:
             self.notebook.set_show_tabs(False)
         self.notebook.set_show_border(False)
         # make a spinner view to display while the applist is loading
@@ -368,23 +369,6 @@ class SoftwarePane(Gtk.VBox, BasePane):
             self.action_bar.set_label(
                         label, link_result=self._show_nonapp_pkgs)
 
-    def _on_label_app_list_header_activate_link(self, link, uri):
-        #print "actiavte: ", link, uri
-        if uri.startswith("search:"):
-            self.searchentry.set_text(uri[len("search:"):])
-        elif uri.startswith("search-all:"):
-            self.unset_current_category()
-            self.refresh_apps()
-        elif uri.startswith("search-parent:"):
-            self.apps_subcategory = None
-            self.refresh_apps()
-        elif uri.startswith("search-unsupported:"):
-            self.apps_filter.set_supported_only(False)
-            self.refresh_apps()
-        # FIXME: add ability to remove categories restriction here
-        # True stops event propergation
-        return True
-
     def _show_nonapp_pkgs(self):
         self.nonapps_visible = NonAppVisibility.ALWAYS_VISIBLE
         self.refresh_apps()
@@ -503,37 +487,37 @@ class SoftwarePane(Gtk.VBox, BasePane):
                                                    None, False)
 
     def on_search_terms_changed(self, terms):
-        " stub implementation "
+        """Stub implementation."""
         pass
 
-    def on_db_reopen(self):
-        " stub implementation "
-        pass
+    def on_db_reopen(self, db):
+        """Stub implementation."""
+        LOG.debug("%r: on_db_reopen (db is %r).", self.__class__.__name__, db)
 
     def is_category_view_showing(self):
-        " stub implementation "
+        """Stub implementation."""
         pass
 
     def is_applist_view_showing(self):
-        " stub implementation "
+        """Stub implementation."""
         pass
 
     def is_app_details_view_showing(self):
-        " stub implementation "
+        """Stub implementation."""
         pass
 
     def get_current_app(self):
-        " stub implementation "
+        """Stub implementation."""
         pass
 
     def on_application_selected(self, widget, app):
-        " stub implementation "
+        """Stub implementation."""
         pass
 
     def get_current_category(self):
-        " stub implementation "
+        """Stub implementation."""
         pass
 
     def unset_current_category(self):
-        " stub implementation "
+        """Stub implementation."""
         pass
