@@ -63,17 +63,13 @@ class AppTreeView(Gtk.TreeView):
 
         self.set_headers_visible(False)
 
-        # a11y: this is a cell renderer that only displays a icon, but still
-        #       has a markup property for orca and friends
-        # we use it so that orca and other a11y tools get proper text to read
-        # it needs to be the first one, because that is what the tools look
-        # at by default
-        tr = CellRendererAppView(icons,
+        # our custom renderer
+        self._renderer = CellRendererAppView(icons,
                                  self.create_pango_layout(''),
                                  show_ratings,
                                  Icons.INSTALLED_OVERLAY)
-        tr.set_pixbuf_width(32)
-        tr.set_button_spacing(em(0.3))
+        self._renderer.set_pixbuf_width(32)
+        self._renderer.set_button_spacing(em(0.3))
 
         # create buttons and set initial strings
         info = CellButtonRenderer(self,
@@ -89,41 +85,50 @@ class AppTreeView(Gtk.TreeView):
                  self.VARIANT_REMOVE: _('Remove'),
                  self.VARIANT_PURCHASE: _(u'Buy\u2026')})
 
-        tr.button_pack_start(info)
-        tr.button_pack_end(action)
+        self._renderer.button_pack_start(info)
+        self._renderer.button_pack_end(action)
 
-        column = Gtk.TreeViewColumn("Applications", tr,
-                                    application=AppGenericStore.COL_ROW_DATA)
-        column.set_cell_data_func(tr, self._cell_data_func_cb)
-        column.set_fixed_width(200)
-        column.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
-        self.append_column(column)
+        self._column = Gtk.TreeViewColumn(
+            "Applications", self._renderer,
+            application=AppGenericStore.COL_ROW_DATA)
+        self._column.set_cell_data_func(
+            self._renderer, self._cell_data_func_cb)
+        self._column.set_fixed_width(200)
+        self._column.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
+        self.append_column(self._column)
 
         # network status watcher
         watcher = get_network_watcher()
-        watcher.connect("changed", self._on_net_state_changed, tr)
+        watcher.connect("changed", self._on_net_state_changed, self._renderer)
 
         # custom cursor
         self._cursor_hand = Gdk.Cursor.new(Gdk.CursorType.HAND2)
 
-        self.connect("style-updated", self._on_style_updated, tr)
+        self.connect("style-updated", self._on_style_updated, self._renderer)
         # button and motion are "special"
-        self.connect("button-press-event", self._on_button_press_event, tr)
-        self.connect("button-release-event", self._on_button_release_event, tr)
-        self.connect("key-press-event", self._on_key_press_event, tr)
-        self.connect("key-release-event", self._on_key_release_event, tr)
-        self.connect("motion-notify-event", self._on_motion, tr)
-        self.connect("cursor-changed", self._on_cursor_changed, tr)
+        self.connect("button-press-event", self._on_button_press_event,
+                     self._renderer)
+        self.connect("button-release-event", self._on_button_release_event,
+                     self._renderer)
+        self.connect("key-press-event", self._on_key_press_event,
+                     self._renderer)
+        self.connect("key-release-event", self._on_key_release_event,
+                     self._renderer)
+        self.connect("motion-notify-event", self._on_motion, self._renderer)
+        self.connect("cursor-changed", self._on_cursor_changed, self._renderer)
         # our own "activate" handler
-        self.connect("row-activated", self._on_row_activated, tr)
+        self.connect("row-activated", self._on_row_activated, self._renderer)
 
         self.backend = get_install_backend()
         self._transactions_connected = False
-        self.connect('realize', self._on_realize, tr)
+        self.connect('realize', self._on_realize, self._renderer)
 
     @property
     def appmodel(self):
         model = self.get_model()
+        # FIXME: would be nice if that would be less ugly,
+        # because we use a treefilter we need to get the "real"
+        # model first
         if isinstance(model, Gtk.TreeModelFilter):
             return model.get_model()
         return model
@@ -144,6 +149,15 @@ class AppTreeView(Gtk.TreeView):
             model.clear()
             self.set_model(model)
 
+    def set_model(self, model):
+        # the set_cell_data_func() calls here are a workaround for bug
+        # LP: #986186 - once that is fixed upstream we can revert this
+        # and remove the entire "set_model" again
+        self._column.set_cell_data_func(self._renderer, None)
+        Gtk.TreeView.set_model(self, model)
+        self._column.set_cell_data_func(
+            self._renderer, self._cell_data_func_cb)
+
     def expand_path(self, path):
         if path is not None and not isinstance(path, Gtk.TreePath):
             raise TypeError("Expects Gtk.TreePath or None, got %s" %
@@ -494,7 +508,7 @@ class AppTreeView(Gtk.TreeView):
                     model, it = sel.get_selected()
                     path = model.get_path(it)
                     if path:
-                        self._init_activated(btn, self.get_model(), path)
+                        self._init_activated(btn, model, path)
                         btn.has_focus = False
                         r = True
                     break
@@ -510,7 +524,6 @@ class AppTreeView(Gtk.TreeView):
                             btn,
                             btn.name,
                             app,
-                            model,
                             path)
 
     def _cell_data_func_cb(self, col, cell, model, it, user_data):
@@ -537,28 +550,29 @@ class AppTreeView(Gtk.TreeView):
         raw = model[path][AppGenericStore.COL_ROW_DATA]
         if self.rowref_is_category(raw):
             text = raw.display_name
-        else:
+        elif raw:
             text = self.db.get_pkgname(raw)
+        else:
+            # this can happen for empty/not-yet-loaded row, LP: #981992
+            text = ""
         cell.set_property('text', text)
 
-    def _app_activated_cb(self, btn, btn_id, app, store, path):
+    def _app_activated_cb(self, btn, btn_id, app, path):
         if self.rowref_is_category(app):
             return
+        model = self.appmodel
+        # don't continue if we don't have a valid model (LP: #969907)
+        if not model:
+            return
 
-        # FIXME: would be nice if that would be more elegant
-        # because we use a treefilter we need to get the "real"
-        # model first
-        if type(store) is Gtk.TreeModelFilter:
-            store = store.get_model()
-
-        pkgname = self.appmodel.get_pkgname(app)
+        pkgname = model.get_pkgname(app)
 
         if btn_id == CellButtonIDs.INFO:
             self.app_view.emit("application-activated",
-                               self.appmodel.get_application(app))
+                               model.get_application(app))
         elif btn_id == CellButtonIDs.ACTION:
             btn.set_sensitive(False)
-            store.row_changed(path, store.get_iter(path))
+            model.row_changed(path, model.get_iter(path))
             app_manager = get_appmanager()
             # be sure we dont request an action for a pkg with
             # pre-existing actions
@@ -567,19 +581,19 @@ class AppTreeView(Gtk.TreeView):
                               " '%s'" % pkgname)
                 return False
             self._action_block_list.append(pkgname)
-            if self.appmodel.is_installed(app):
+            if model.is_installed(app):
                 action = AppActions.REMOVE
-            elif self.appmodel.is_purchasable(app):
-                app_manager.buy_app(self.appmodel.get_application(app))
-                store.notify_action_request(app, path)
+            elif model.is_purchasable(app):
+                app_manager.buy_app(model.get_application(app))
+                model.notify_action_request(app, path)
                 return
             else:
                 action = AppActions.INSTALL
 
-            store.notify_action_request(app, path)
+            model.notify_action_request(app, path)
 
             app_manager.request_action(
-                self.appmodel.get_application(app), [], [],
+                model.get_application(app), [], [],
                 action)
         return False
 
