@@ -114,19 +114,12 @@ class UIReviewsList(Gtk.VBox):
         label.set_padding(6, 6)
         label.set_use_markup(True)
         label.set_alignment(0, 0.5)
-        self.pack_start(label, False, False, 0)
+        self.header = Gtk.HBox()
+        self.header.pack_start(label, False, False, 0)
 
         # header
-        self.header = Gtk.HBox()
         self.header.set_spacing(StockEms.MEDIUM)
 
-        self.new_review = Link(_('Write your own review'))
-        self.new_review.connect('clicked', lambda w: self.emit('new-review'))
-        inner_vb = Gtk.VBox()
-        inner_vb.pack_start(self.new_review, False, False, StockEms.SMALL)
-        self.header.pack_start(inner_vb, False, False, 0)
-        self.pack_start(self.header, False, False, 0)
-
         # review sort method
         self.sort_combo = Gtk.ComboBoxText()
         self._current_sort = 0
@@ -151,10 +144,17 @@ class UIReviewsList(Gtk.VBox):
             "changed", self._on_different_review_language_clicked)
         self.header.pack_end(self.review_language, False, True, 0)
 
+        self.pack_start(self.header, False, False, 0)
+        self.reviews_info_hbox = Gtk.HBox()
+        self.new_review = Link(_('Write your own review'))
+        self.new_review.connect('clicked', lambda w: self.emit('new-review'))
+        self.reviews_info_hbox.pack_start(
+            self.new_review, False, False, StockEms.SMALL)
+        self.pack_start(self.reviews_info_hbox, True, True, 0)
         # this is where the reviews end up
         self.vbox = Gtk.VBox()
         self.vbox.set_spacing(24)
-        self.pack_start(self.vbox, True, True, 0)
+        self.pack_end(self.vbox, True, True, 0)
 
         # ensure network state updates
         self.no_network_msg = None
@@ -194,11 +194,19 @@ class UIReviewsList(Gtk.VBox):
             UI vbox out of them
         """
         self.logged_in_person = get_person_from_config()
+        is_first_for_version = None
         if self.reviews:
+            previous_review = None
             for r in self.reviews:
                 pkgversion = self._parent.app_details.version
+                if previous_review:
+                    is_first_for_version = previous_review.version != r.version
+                else:
+                    is_first_for_version = True
+                previous_review = r
                 review = UIReview(r, pkgversion, self.logged_in_person,
-                    self.useful_votes)
+                    self.useful_votes, is_first_for_version)
+                review.show_all()
                 self.vbox.pack_start(review, True, True, 0)
 
     def _be_the_first_to_review(self):
@@ -213,7 +221,8 @@ class UIReviewsList(Gtk.VBox):
         self.install_first_label = Gtk.Label(label=s)
         self.install_first_label.set_use_markup(True)
         self.install_first_label.set_alignment(1.0, 0.5)
-        self.header.pack_start(self.install_first_label, False, False, 0)
+        self.reviews_info_hbox.pack_start(
+            self.install_first_label, False, False, 0)
         self.install_first_label.show()
 
     # FIXME: this needs to be smarter in the future as we will
@@ -273,7 +282,6 @@ class UIReviewsList(Gtk.VBox):
         # always hide spinner and call _fill (fine if there is nothing to do)
         self.hide_spinner()
         self._fill()
-        self.vbox.show_all()
 
         if self.reviews:
             # adjust label if we have reviews
@@ -398,7 +406,8 @@ class UIReview(Gtk.VBox):
         useful/inappropriate etc
     """
     def __init__(self, review_data=None, app_version=None,
-                 logged_in_person=None, useful_votes=None):
+                 logged_in_person=None, useful_votes=None,
+                 first_for_version=True):
         GObject.GObject.__init__(self)
         self.set_spacing(StockEms.SMALL)
 
@@ -438,8 +447,8 @@ class UIReview(Gtk.VBox):
         self.usefulness_error = False
         self.delete_error = False
         self.modify_error = False
-
-        self.pack_start(self.version_label, False, False, 0)
+        if first_for_version:
+            self.pack_start(self.version_label, False, False, 0)
         self.pack_start(self.header, False, False, 0)
         self.pack_start(self.body, False, False, 0)
         self.pack_start(self.footer, False, False, StockEms.SMALL)
@@ -452,17 +461,10 @@ class UIReview(Gtk.VBox):
         self._allocation = None
 
         if review_data:
-        # when this is mapped, show/hide widgets that are network sensitive
-        # this ensures that even with show_all() we show the right stuff
-            self.connect('realize',
-                         self._on_realize,
-                         review_data,
-                         app_version,
-                         logged_in_person,
-                         useful_votes)
-
-    def _on_realize(self, widget, *content):
-        self._build(*content)
+            self._build(review_data,
+                        app_version,
+                        logged_in_person,
+                        useful_votes)
 
     def _on_report_abuse_clicked(self, button):
         reviews = self.get_ancestor(UIReviewsList)
@@ -657,6 +659,7 @@ class UIReview(Gtk.VBox):
         text = Gtk.Label()
         text.set_text(review_data.review_text)
         text.set_line_wrap(True)
+        text.set_line_wrap_mode(Pango.WrapMode.WORD_CHAR)
         text.set_selectable(True)
         text.set_alignment(0, 0)
 
@@ -738,14 +741,14 @@ class UIReview(Gtk.VBox):
         if network_state_is_connected():
             self.likebox.show()
             self.useful.show()
-            self.complain.show()
+            self.flagbox.show()
         else:
             self.likebox.hide()
             # we hide the useful box because if its there it says something
             # like "10 people found this useful. Did you?" but you can't
             # actually submit anything without network
             self.useful.hide()
-            self.complain.hide()
+            self.flagbox.hide()
 
     def _get_usefulness_label(self, current_user_reviewer,
                               useful_total, useful_favorable, already_voted):
@@ -839,7 +842,6 @@ class UIReview(Gtk.VBox):
                 # verb, it won't need a question mark.
                 self.complain = Link(m % _('Inappropriate?'))
                 self.complain.set_name("subtle-label")
-                self.complain.set_sensitive(network_state_is_connected())
                 self.flagbox.pack_start(self.complain, False, False, 0)
                 self.complain.connect('clicked', self._on_report_abuse_clicked)
             self.flagbox.show_all()
