@@ -406,9 +406,13 @@ installedsize	2	# installed size
 packagesize	3	# package size
 app-popcon	4	# app-install .desktop popcon rank
 """
-        open("axi-test-values","w").write(s)
+        fname = "axi-test-values"
+        with open(fname, "w") as f:
+            f.write(s)
+        self.addCleanup(os.remove, fname)
+
         #db = StoreDatabase("/var/cache/software-center/xapian", self.cache)
-        axi_values = parse_axi_values_file("axi-test-values")
+        axi_values = parse_axi_values_file(fname)
         self.assertNotEqual(axi_values, {})
         print axi_values
 
@@ -420,7 +424,7 @@ app-popcon	4	# app-install .desktop popcon rank
         self.assertTrue(len(details.tags) > 2)
 
     def test_app_enquire(self):
-        db = StoreDatabase("/var/cache/software-center/xapian", self.cache)
+        db = StoreDatabase(cache=self.cache)
         db.open()
         # test the AppEnquire engine
         enquirer = AppEnquire(self.cache, db)
@@ -428,7 +432,14 @@ app-popcon	4	# app-install .desktop popcon rank
                            nonblocking_load=False)
         self.assertTrue(len(enquirer.get_docids()) > 0)
         # FIXME: test more of the interface
-        
+
+    def test_is_pkgname_known(self):
+        db = StoreDatabase(cache=self.cache)
+        db.open()
+        self.assertTrue(db.is_pkgname_known("apt"))
+        self.assertFalse(db.is_pkgname_known("i+am-not-a-pkg"))
+
+
 class UtilsTestCase(unittest.TestCase):
 
     def test_utils_get_installed_package_list(self):
@@ -529,6 +540,7 @@ class AppDetailsSCAApplicationParser(unittest.TestCase):
 
     @patch("softwarecenter.db.update.get_region_cached")
     def test_region_blacklist(self, get_region_cached_mock):
+        """Test that the region blacklist ignores blacklisted locations"""
         from softwarecenter.region import REGION_BLACKLIST_TAG
         get_region_cached_mock.return_value = { "countrycode" : "es",
                                               }
@@ -540,6 +552,51 @@ class AppDetailsSCAApplicationParser(unittest.TestCase):
         parser = SCAApplicationParser(item)
         doc = make_doc_from_parser(parser, self.db._aptcache)
         self.assertEqual(doc, None)
+
+    @patch("softwarecenter.db.update.get_region_cached")
+    def test_region_blacklist_blacklists(self, get_region_cached_mock):
+        """Test that the region blacklist adds non-blacklisted locations"""
+        from softwarecenter.region import REGION_BLACKLIST_TAG
+        get_region_cached_mock.return_value = { "countrycode" : "de",
+                                              }
+        app_dict = make_software_center_agent_app_dict()
+        app_dict["debtags"] = ["%s%s" % (REGION_BLACKLIST_TAG, "ES"),
+                              ]
+        # see _get_app_details_from_app_dict
+        item = PistonResponseObject.from_dict(app_dict)
+        parser = SCAApplicationParser(item)
+        doc = make_doc_from_parser(parser, self.db._aptcache)
+        self.assertNotEqual(doc, None)
+
+    @patch("softwarecenter.db.update.get_region_cached")
+    def test_region_whitelist_whitelists(self, get_region_cached_mock):
+        """Test that the whitelist adds whitelisted locations"""
+        from softwarecenter.region import REGION_WHITELIST_TAG
+        get_region_cached_mock.return_value = { "countrycode" : "es",
+                                              }
+        app_dict = make_software_center_agent_app_dict()
+        app_dict["debtags"] = ["%s%s" % (REGION_WHITELIST_TAG, "ES"),
+                              ]
+        # see _get_app_details_from_app_dict
+        item = PistonResponseObject.from_dict(app_dict)
+        parser = SCAApplicationParser(item)
+        doc = make_doc_from_parser(parser, self.db._aptcache)
+        self.assertNotEqual(doc, None)
+
+    @patch("softwarecenter.db.update.get_region_cached")
+    def test_region_whitelist_blacklists(self, get_region_cached_mock):
+        """Test that the whitelist ignores non-whitelist locations"""
+        from softwarecenter.region import REGION_WHITELIST_TAG
+        get_region_cached_mock.return_value = { "countrycode" : "de",
+                                              }
+        app_dict = make_software_center_agent_app_dict()
+        app_dict["debtags"] = ["%s%s" % (REGION_WHITELIST_TAG, "ES"),
+                              ]
+        # see _get_app_details_from_app_dict
+        item = PistonResponseObject.from_dict(app_dict)
+        parser = SCAApplicationParser(item)
+        doc = make_doc_from_parser(parser, self.db._aptcache)
+        self.assertEqual(doc, None)
         
 
 class AppDetailsPkgStateTestCase(unittest.TestCase):
